<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="编号">
              <el-input v-model="querys[0].value" clearable placeholder="请输入编号" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="名称">
              <el-input v-model="querys[1].value" clearable placeholder="请输入名称" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                     style="margin-left: 10px"
                     type="danger">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData"
                :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed label="序号" type="index" width="55" />
        <el-table-column fixed label="编号" prop="code" show-overflow-tooltip />
        <el-table-column fixed label="名称" prop="name" show-overflow-tooltip />
        <el-table-column fixed label="职责描述" prop="description" show-overflow-tooltip />
        <el-table-column fixed label="负责区域" prop="area" show-overflow-tooltip>
          <template slot-scope="scope">
            <!-- <span v-for="(item,index) in scope.row.deviceBaseAreas" :key="index">{{item.name}}</span> -->
            <span>{{ scope.row.deviceBaseAreas.map(it => it.name).join(',') }}</span>
          </template>
        </el-table-column>
        <el-table-column fixed label="创建时间" prop="createTime" show-overflow-tooltip sortable />
        <el-table-column fixed label="修改时间" prop="updateTime" show-overflow-tooltip sortable />
        <!-- <el-table-column align="right" width="120px" label="操作" :index="999">
          <template slot-scope="scope">
            <el-button
              size="mini"
              type="primary"
              circle
              icon="el-icon-map-location"
              @click="$refs.gisMapDrawer.setArea(scope.row)"
            />
          </template>
        </el-table-column>-->
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page"
                     :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background class="bbsl-pagination"
                     layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <CmgtDutyJobFormDialog ref="formModal" :equipmentList="equipmentList" />
    <GisMapDrawer ref="gisMapDrawer" @confirm="mapConfirm" />
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import GisMapDrawer from '@/views/Manage/components/GisMapDrawer.vue'

import CmgtDutyJobApi from '@/views/Manage/duty/api/CmgtDutyJobApi'
import CmgtDutyJobFormDialog from '@/views/Manage/duty/components/CmgtDutyJobFormDialog'
import equipmentManage from '@/api/device/equipmentManage.js'

export default {
  name: 'CmgtDutyJobManage',
  components: {
    CmgtDutyJobFormDialog,
    GisMapDrawer
  },
  mixins: [TableMixin],
  data() {
    return {
      mapVisible: false,
      url: {
        delete: '/manager/cmgtDutyJob/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      equipmentList: [] // 关联区域列表
    }
  },
  created() {
    this.getEquipmentList()
  },
  mounted() {
  },
  methods: {
    // 获取关联区域列表
    getEquipmentList() {
      equipmentManage.loadAreaTree({id: '0'}, res => {
        this.equipmentList = res.value
      })
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      CmgtDutyJobApi.loadCmgtDutyJob(this.queryParam, res => {
        console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        // console.log('///', this.tableData)
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    mapConfirm(val, row) {
      // console.log('=======val========', val)
      row.area = val.toString()
      this.loading = true
      CmgtDutyJobApi.editCmgtDutyJob(row, res => {
        this.loading = false
        if (res.state) {
          this.$notify({
            type: 'success',
            message: '设置【' + row.name + '】的岗位区域成功',
            duration: 2000
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
